@@ -1,16 +1,18 @@
+from piso.graph import adjacency_matrix
 from piso.intervalarray import (
     complement,
+    contains,
     coverage,
     difference,
-    get_indexer,
     intersection,
     isdisjoint,
     issubset,
     issuperset,
+    split,
     symmetric_difference,
     union,
 )
-from piso.ndframe import lookup
+from piso.ndframe import join, lookup
 
 
 def register_accessors():
