@@ -3,7 +3,7 @@ import warnings
 import pandas as pd
 
 import piso.docstrings.accessor as docstrings
-from piso import intervalarray
+from piso import graph, intervalarray
 from piso._decorators import Appender
 
 
@@ -155,11 +155,27 @@ class ArrayAccessor:
             domain,
         )
 
-    @Appender(docstrings.get_indexer_docstring, join="\n", indents=1)
-    def get_indexer(self, x):
-        return intervalarray.get_indexer(
+    @Appender(docstrings.contains_docstring, join="\n", indents=1)
+    def contains(self, x, include_index=True):
+        return intervalarray.contains(
             self._interval_array,
             x,
+            include_index,
+        )
+
+    @Appender(docstrings.split_docstring, join="\n", indents=1)
+    def split(self, x):
+        return intervalarray.split(
+            self._interval_array,
+            x,
+        )
+
+    @Appender(docstrings.adjacency_matrix_docstring, join="\n", indents=1)
+    def adjacency_matrix(self, edges="intersect", include_index=True):
+        return graph.adjacency_matrix(
+            self._interval_array,
+            edges=edges,
+            include_index=include_index,
         )
 
 
