@@ -544,6 +544,9 @@ symmetric_difference_docstring = operation_template_doc.format(
 isdisjoint_doc = (
     """
 Indicates whether one, or more, sets are disjoint or not.
+
+*interval_array* must be left-closed or right-closed if *interval_arrays is non-empty.
+If *interval_array* is the only argument then this restriction does not apply.
 """
     + template_doc
 )
@@ -599,6 +602,7 @@ Parameters
 ----------
 interval_array : :class:`pandas.IntervalIndex` or :class:`pandas.arrays.IntervalArray`
     Contains the (possibly overlapping) intervals which partially, or wholly cover the domain.
+    May be left-closed, right-closed, both, or neither.
 domain : :py:class:`tuple`, :class:`pandas.Interval`, :class:`pandas.IntervalIndex` or :class:`pandas.arrays.IntervalArray`, optional
     Specifies the domain over which to calculate the "coverage".  If *domain* is `None`,
     then the domain is considered to be the extremities of the intervals contained in *interval_array*
@@ -646,7 +650,7 @@ Equivalent to the set difference of the domain and the intervals in the array.
 Parameters
 ----------
 interval_array : :class:`pandas.IntervalIndex` or :class:`pandas.arrays.IntervalArray`
-    Contains the (possibly overlapping) intervals.
+    Contains the (possibly overlapping) intervals.  Must be left-closed or right-closed.
 domain : :py:class:`tuple`, :class:`pandas.Interval`, :class:`pandas.IntervalIndex` or :class:`pandas.arrays.IntervalArray`, optional
     Specifies the domain over which to calculate the "complement".  If *domain* is `None`,
     then the domain is considered to be the extremities of the intervals contained in *interval_array*
@@ -699,6 +703,8 @@ get_indexer_docstring = """
 Given a set of disjoint intervals and a value, or vector, *x* returns the
 index positions of the interval which contains each value in x.
 
+*interval_array* can be left-closed, right-closed, both or neither.
+
 Parameters
 ----------
 interval_array : :class:`pandas.IntervalIndex` or :class:`pandas.arrays.IntervalArray`
@@ -734,3 +740,101 @@ Examples
 >>> piso.get_indexer(arr, [1,2,7,13])
 array([ 0,  0,  1, -1], dtype=int64)
 """
+
+
+contains_docstring = """
+Check pair-wise if a set of intervals contains a set of values
+
+Returns a 2-dimensional boolean mask *M* of shape *(m,n)* where *m* is the number of intervals, and
+*n* is the number of points.  The element in the i-th row and j-th column is True if
+the i-th interval contains the j-th point.
+
+Parameters
+----------
+interval_array : :class:`pandas.IntervalIndex` or :class:`pandas.arrays.IntervalArray`
+    Contains the intervals.  May be left-closed, right-closed, both, or neither.
+x : scalar, or array-like of scalars
+    Values in *x* should belong to the same domain as the intervals in *interval_array*.
+include_index : boolean, default True
+    Indicates whether to return a :class:`numpy.ndarray` or :class:`pandas.DataFrame` indexed
+    by *interval_array* and column names equal to *x*
+
+Returns
+----------
+:class:`numpy.ndarray` or :class:`pandas.DataFrame`
+    Two dimensional and boolean valued.  Return type dependent on *include_index*.
+
+Examples
+-----------
+
+>>> import pandas as pd
+>>> import piso
+
+>>> arr = pd.arrays.IntervalArray.from_tuples(
+...     [(0, 4), (2, 5)],
+... )
+
+>>> piso.contains(arr, 1)
+            1
+(0, 4]   True
+(2, 5]  False
+
+>>> piso.contains(arr, [0, 1, 3, 4])
+            0      1     3     4
+(0, 4]  False   True  True  True
+(2, 5]  False  False  True  True
+
+>>> piso.contains(arr, [0, 1, 3, 4], include_index=False)
+array([[False,  True,  True,  True],
+       [False, False,  True,  True]])
+
+>>> piso.contains(pd.IntervalIndex.from_tuples([(0,2)]), 1, include_index=False)
+array([[ True]])
+"""
+
+split_docstring = """
+Given a set of intervals, and break points, splits the intervals into pieces wherever
+the overlap a break point.
+
+Parameters
+----------
+interval_array : :class:`pandas.IntervalIndex` or :class:`pandas.arrays.IntervalArray`
+    Contains the (possibly overlapping) intervals.  May be left-closed, right-closed, both, or neither.
+x : scalar, or array-like of scalars
+    Values in *x* should belong to the same domain as the intervals in *interval_array*.
+    May contain duplicates and be unsorted.
+
+Returns
+----------
+:class:`pandas.IntervalIndex` or :class:`pandas.arrays.IntervalArray`
+    Return type will be the same type as *interval_array*
+
+Examples
+-----------
+
+>>> import pandas as pd
+>>> import piso
+
+>>> arr = pd.arrays.IntervalArray.from_tuples(
+...     [(0, 4), (2, 5)],
+... )
+
+>>> piso.split(arr, 3)
+<IntervalArray>
+[(0, 3], (3, 4], (2, 3], (3, 5]]
+Length: 4, closed: right, dtype: interval[int64]
+
+>>> piso.split(arr, [3,3,3,3])
+<IntervalArray>
+[(0, 3], (3, 4], (2, 3], (3, 5]]
+Length: 4, closed: right, dtype: interval[int64]
+
+>>> arr = pd.IntervalIndex.from_tuples(
+...     [(0, 4), (2, 5)], closed="neither",
+... )
+
+>>> piso.split(arr, [1, 6, 4])
+IntervalIndex([(0.0, 1.0), (1.0, 4.0), (2.0, 4.0), (4.0, 5.0)],
+              closed='neither',
+              dtype='interval[float64]')
+"""
